from setuptools import setup, find_packages

VERSION = '2.0.3'
DESCRIPTION = 'Making connection between bython and Node-RED'
LONG_DESCRIPTION = 'This package send and recieve data with Node-RED'

# Setting up
setup(
    name="am_red_channel",
    version=VERSION,
    author="Amr Mostafa (Amr_MAM)",
    author_email="<amr.mostafa.abbas@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['requests'],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets', 'Node-RED'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



import requests as _req
from am_red_channel._consts import *

def AM_SendDataSameDevice(id, data):
    id_url = k_AM_localNodeURL + str(id)    
    
    hConfigurations = {
        'Content-Type': k_AM_contentType,
    }
    
    params = {          
        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
        'AM_Auth_Signature': 'AM-from-Python',
    }

    try:
        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, params=params, data = str(data))
        if(response.status_code == 200) :
            return K_AM_success
        else :
            return k_AM_failure
    except:
        return k_AM_failed_to_connect


def AM_GetDataSameDevice(id):
    id_url = k_AM_localNodeURL + str(id)   

    hConfigurations={
        'Content-Type': k_AM_contentType,
    }

    params = {          
        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
        'AM_Auth_Signature': 'AM-from-Python',
    }

    try:
        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations, params=params)
        return response.text
    except:
        return k_AM_failed_to_connect



def AM_SendData(id, node_red_url, data):
    id_url = ""
    
    if(str(node_red_url).endswith('/')):
        id_url = str(node_red_url) + str(id)
    else :
        id_url = str(node_red_url) + "/" + str(id)

    hConfigurations={
        'Content-Type': k_AM_contentType,
    }
    
    params = {          
        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
        'AM_Auth_Signature': 'AM-from-Python',
    }

    try:
        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, params=params, data = str(data))
        if(response.status_code == 200) :
            return K_AM_success
        else :
            return k_AM_failure
    except:
        return k_AM_failed_to_connect



def AM_GetData(id, node_red_url):
    id_url = ""
    
    if(str(node_red_url).endswith('/')):
        id_url = str(node_red_url) + str(id)
    else :
        id_url = str(node_red_url) + "/" + str(id)

    hConfigurations={
        'Content-Type': k_AM_contentType,
    }

    params = {          
        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
        'AM_Auth_Signature': 'AM-from-Python',
    }

    try:
        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations, params=params)
        return response.text
    except:
        return k_AM_failed_to_connect




k_AM_localNodeURL = 'http://127.0.0.1:1880/'
k_AM_failure = 'failure'
K_AM_success = 'success'
k_AM_GET = 'GET'
k_AM_SEND = 'POST'
k_AM_contentType = 'Text/Plain'
k_AM_failed_to_connect = 'failed to connect'